"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Any = void 0;
const jsonEntityFn_1 = require("./jsonEntityFn");
/**
 * Set the type of the array items.
 *
 * ## Example
 *
 * ```typescript
 * class Model {
 *    @Any()
 *    property: any;
 *
 *    @Any(String, Number, Boolean)
 *    property: string | number | boolean;
 * }
 * ```
 *
 * Will produce:
 *
 * ```json
 * {
 *   "type": "object",
 *   "properties": {
 *     "property": {
 *       "type": ["integer", "number", "string", "boolean", "array", "object", "null"]
 *     }
 *   }
 * }
 * ```
 *
 * @returns {Function}
 * @decorator
 * @validation
 * @swagger
 * @schema
 * @input
 */
function Any(...types) {
    return (0, jsonEntityFn_1.JsonEntityFn)((store) => {
        store.itemSchema.any(...types);
    });
}
exports.Any = Any;
//# sourceMappingURL=any.js.map